@@ -7,10 +7,11 @@
 
 //extern "C" {
 #include <R.h>
-#include <Rinternals.h>
+//#include <Rinternals.h>
 #include <Rdefines.h>
 #include <R_ext/RS.h>
 #include <R_ext/Lapack.h>
+#include <R_ext/Error.h>
 //}
 
 /**
